# Copyright (c) 2000-2013, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define section         free
%define _binary_payload w9.gzdio
%define _source_payload w9.gzdio
%define _binary_filedigest_algorithm 1
%define _source_filedigest_algorithm 1

Name:           jvnet-msv
Summary:        Multi-Schema XML Validator
Url:            http://msv.java.net/
Version:        2011.1
Release:        2%{?dist}
Epoch:          0
License:        BSD
Group:          Development/Libraries
Source0:        msv-2011.1.tar.gz
# git clone git://github.com/kohsuke/msv.git
# cd msv
# git tag -l
# git archive msv-2011.1 > ../msv-2011.1.tar
# gzip ../msv-2011.1.tar

Source1:        %{name}-settings.xml
Source2:        %{name}-jpp-depmap.xml
Patch0:         jvnet-msv-pom.patch
Patch1:         jvnet-msv-xsdlib-pom.patch
Patch2:         jvnet-msv-msv-pom.patch

BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  ant >= 0:1.7.1
BuildRequires:  maven2 >= 0:2.0.8
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-eclipse
BuildRequires:  maven2-plugin-idea
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-plugin
BuildRequires:  maven2-plugin-release
BuildRequires:  maven2-plugin-remote-resources
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven2-plugin-shade
BuildRequires:  maven-surefire-maven-plugin
BuildRequires:  maven-surefire-provider-junit4
BuildRequires:  apache-felix-maven-bundle-plugin
BuildRequires:  oss-parent


Requires(post):    jpackage-utils >= 0:1.7.5
Requires(postun):  jpackage-utils >= 0:1.7.5
Requires:  java >= 0:1.6.0

BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-buildroot

%description
The Oracle Multi-Schema XML Validator (MSV) is a Java 
technology tool to validate XML documents against several 
kinds of XML schemata. It supports RELAX NG, RELAX Namespace,
RELAX Core, TREX, XML DTDs, and a subset of XML Schema Part 1.
This latest (version 1.2) release includes several bug fixes
and adds better conformance to RELAX NG/W3C XML standards
and JAXP masquerading. This download package includes
binaries, source code, and detailed documentation.
The project is licensed under the BSD license.
This tool is:
* A command line tool that can read XML documents and 
  validate them against a schema (DTD/RELAX/TREX/W3C). 
  If an error is found, error messages are provided.
* A library that can be incorporated into Java 
  applications as a validator. 

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%prep
%setup -q -c
chmod -R go=u-w *
for j in $(find . -name "*.jar"); do
    mv $j $j.no
done
cp %{SOURCE1} settings.xml
%patch0 -b .sav0
%patch1 -b .sav1
%patch2 -b .sav2

%build
sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml

export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository

mkdir external_repo
ln -s %{_javadir} external_repo/JPP

export SETTINGS=$(pwd)/settings.xml

mvn-jpp \
        -e \
        -s $SETTINGS \
        -Dmaven2.jpp.depmap.file=%{SOURCE2} \
        -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
        -Dmaven.test.failure.ignore=true \
        install 
mvn-jpp \
        -e \
        -s $SETTINGS \
        -Dmaven2.jpp.depmap.file=%{SOURCE2} \
        -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
        javadoc:aggregate

%install
rm -rf $RPM_BUILD_ROOT

# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}/%{name}
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms

%add_to_maven_depmap net.java.dev.msv msv %{version} JPP/%{name} msv
install -m 644 pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-msv.pom

%add_to_maven_depmap net.java.dev.msv msv-parent %{version} JPP/%{name} msv-parent
install -m 644 parent/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-msv-parent.pom

%add_to_maven_depmap net.java.dev.msv msv-generator %{version} JPP/%{name} msv-generator
install -m 644 generator/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-msv-generator.pom
install -m 644 generator/target/msv-generator-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/msv-generator-%{version}.jar

%add_to_maven_depmap net.java.dev.msv msv-core %{version} JPP/%{name} msv-core
install -m 644 msv/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-msv-core.pom
install -m 644 msv/target/msv-core-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/msv-core-%{version}.jar

%add_to_maven_depmap net.java.dev.msv msv-rngconverter %{version} JPP/%{name} msv-rngconverter
install -m 644 rngconverter/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-msv-rngconverter.pom
install -m 644 rngconverter/target/msv-rngconverter-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/msv-rngconverter-%{version}.jar

%add_to_maven_depmap net.java.dev.msv msv-testharness %{version} JPP/%{name} msv-testharness
install -m 644 testharness/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-msv-testharness.pom
install -m 644 testharness/target/msv-testharness-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/msv-testharness-%{version}.jar

%add_to_maven_depmap com.sun.msv.datatype.xsd xsdlib %{version} JPP/%{name} xsdlib
install -m 644 xsdlib/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-xsdlib.pom
install -m 644 xsdlib/target/xsdlib-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/xsdlib-%{version}.jar

(cd $RPM_BUILD_ROOT%{_javadir}/%{name} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`; done)

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr target/site/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(-,root,root)
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/*.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*

%files javadoc
%defattr(-,root,root,-)
%doc %{_javadocdir}/*

%changelog
* Mon Feb 04 2013 Ralph Apel <r.apel at r-apel.de> 0:2011.1-2
- Prevent xzpayload problem

* Fri Jan 11 2013 Ralph Apel <r.apel at r-apel.de> 0:2011.1-1
- First release from this codebase as jvnet-msv

